<?php
/**
 * Custom template tags for this theme.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package ThemeGrill
 * @subpackage Masonic
 * @since 1.0
 */
if (!function_exists('masonic_paging_nav')) :

   /**
    * Display navigation to next/previous set of posts when applicable.
    */
   function masonic_paging_nav() {
      // Don't print empty markup if there's only one page.
      if ($GLOBALS['wp_query']->max_num_pages < 2) {
         return;
      }
      ?>
      <div class="page-navigation clear">
         <div class="underline"></div>
         <hr>
         <h1 class="screen-reader-text"><?php _e('Навигация', 'masonic'); ?></h1>
         <?php if (get_next_posts_link()) : ?>
            <div class="nav-previous"><?php next_posts_link(__('<span><i class="fa fa-arrow-circle-o-left"></i></span> Предыдущие записи', 'masonic')); ?></div>
         <?php endif; ?>

         <?php if (get_previous_posts_link()) : ?>
            <div class="nav-next"><?php previous_posts_link(__('Следующие записи <span><i class="fa fa-arrow-circle-o-right"></i></span>', 'masonic')); ?></div>
         <?php endif; ?>

      </div><!-- .navigation -->
      <div class="underline"></div>
      <hr>
      <?php
   }

endif;

if (!function_exists('masonic_post_nav')) :

   /**
    * Display navigation to next/previous post when applicable.
    */
   function masonic_post_nav() {
      // Don't print empty markup if there's nowhere to navigate.
      $previous = ( is_attachment() ) ? get_post(get_post()->post_parent) : get_adjacent_post(false, '', true);
      $next = get_adjacent_post(false, '', false);

      if (!$next && !$previous) {
         return;
      }
      ?>
      <div class="post-navigation clear">
         <div class="underline"></div>
         <hr>
         <h2 class="screen-reader-text"><?php _e('Навигация', 'masonic'); ?></h2>
         <?php
         previous_post_link('<div class="nav-previous">%link</div>', _x('<span><i class="fa fa-arrow-circle-o-left"></i></span>%title', 'Предыдущие записи', 'masonic'));
         next_post_link('<div class="nav-next">%link</div>', _x('%title<span><i class="fa fa-arrow-circle-o-right"></i></span>', 'Следующие записи', 'masonic'));
         ?>
      </div><!-- .navigation -->
      <div class="underline"></div>
      <hr>
      <?php
   }

endif;

if (!function_exists('masonic_posted_on')) :

   /**
    * Prints HTML with meta information for the current post-date/time and author.
    */
   function masonic_posted_on() {

      if (is_single()) {
         $cat_list = get_the_category_list(__(' ', 'masonic'));
         if ($cat_list && masonic_categorized_blog()) {
            echo '<div class="catagory-type">' . $cat_list . '</div>';
         }
      }

      echo '<div class="entry-date updated fa fa-clock-o"><a href="' . esc_url(get_permalink()) . '" rel="bookmark">' . get_the_date() . '</a></div>';

      echo '<div class="entry-author vcard author fa fa-user"><a class="url fn n" href="' . esc_url(get_author_posts_url(get_the_author_meta('ID'))) . '">' . esc_html(get_the_author()) . '</a></div>';

      if (!is_single()) {
         $categories_list = get_the_category_list(__(', ', 'masonic'));
         if ($categories_list && masonic_categorized_blog()) {
            echo '<div class="entry-standard fa fa-folder-open">' . $categories_list . '</div>';
         }
      }

      if (is_single()) {
         if (comments_open()) :
            ?>
            <div class="entry-date fa fa-comments"><?php comments_popup_link(__('Комментариев нет', 'masonic'), __('1 комментарий', 'masonic'), __('% комментариев', 'masonic')); ?></div>
            <?php
         endif;
      }

      $tags_list = get_the_tag_list('', __(', ', 'masonic'));
      if (is_single()) {
         if ($tags_list) :
            ?>
            <div class="entry-tag fa fa-tags"><?php printf(__(' %1$s', 'masonic'), $tags_list); ?></div>
            <?php
         endif;
      }
   }

endif;

if (!function_exists('the_archive_title')) :

   /**
    * Shim for `the_archive_title()`.
    *
    * Display the archive title based on the queried object.
    *
    * @todo Remove this function when WordPress 4.3 is released.
    *
    * @param string $before Optional. Content to prepend to the title. Default empty.
    * @param string $after  Optional. Content to append to the title. Default empty.
    */
   function the_archive_title($before = '', $after = '') {
      if (is_category()) {
         $title = sprintf(__('Рубрика: %s', 'masonic'), single_cat_title('', false));
      } elseif (is_tag()) {
         $title = sprintf(__('Тег: %s', 'masonic'), single_tag_title('', false));
      } elseif (is_author()) {
         $title = sprintf(__('Автор: %s', 'masonic'), '<span class="vcard">' . get_the_author() . '</span>');
      } elseif (is_year()) {
         $title = sprintf(__('Год: %s', 'masonic'), get_the_date(_x('Y', 'yearly archives date format', 'masonic')));
      } elseif (is_month()) {
         $title = sprintf(__('Месяц: %s', 'masonic'), get_the_date(_x('F Y', 'monthly archives date format', 'masonic')));
      } elseif (is_day()) {
         $title = sprintf(__('День: %s', 'masonic'), get_the_date(_x('F j, Y', 'daily archives date format', 'masonic')));
      } elseif (is_post_type_archive()) {
         $title = sprintf(__('Архивы: %s', 'masonic'), post_type_archive_title('', false));
      } elseif (is_tax()) {
         $tax = get_taxonomy(get_queried_object()->taxonomy);
         /* translators: 1: Taxonomy singular name, 2: Current taxonomy term */
         $title = sprintf(__('%1$s: %2$s', 'masonic'), $tax->labels->singular_name, single_term_title('', false));
      } else {
         $title = __('Архивы', 'masonic');
      }

      /**
       * Filter the archive title.
       *
       * @param string $title Archive title to be displayed.
       */
      $title = apply_filters('get_the_archive_title', $title);

      if (!empty($title)) {
         echo $before . $title . $after;
      }
   }

endif;

if (!function_exists('the_archive_description')) :

   /**
    * Shim for `the_archive_description()`.
    *
    * Display category, tag, or term description.
    *
    * @todo Remove this function when WordPress 4.3 is released.
    *
    * @param string $before Optional. Content to prepend to the description. Default empty.
    * @param string $after  Optional. Content to append to the description. Default empty.
    */
   function the_archive_description($before = '', $after = '') {
      $description = apply_filters('get_the_archive_description', term_description());

      if (!empty($description)) {
         /**
          * Filter the archive description.
          *
          * @see term_description()
          *
          * @param string $description Archive description to be displayed.
          */
         echo $before . $description . $after;
      }
   }

endif;

/**
 * Returns true if a blog has more than 1 category.
 *
 * @return bool
 */
function masonic_categorized_blog() {
   if (false === ( $all_the_cool_cats = get_transient('masonic_categories') )) {
      // Create an array of all the categories that are attached to posts.
      $all_the_cool_cats = get_categories(array(
          'fields' => 'ids',
          'hide_empty' => 1,
          // We only need to know if there is more than one category.
          'number' => 2,
      ));

      // Count the number of categories that are attached to the posts.
      $all_the_cool_cats = count($all_the_cool_cats);

      set_transient('masonic_categories', $all_the_cool_cats);
   }

   if ($all_the_cool_cats > 1) {
      // This blog has more than 1 category so masonic_categorized_blog should return true.
      return true;
   } else {
      // This blog has only 1 category so masonic_categorized_blog should return false.
      return false;
   }
}

/**
 * Flush out the transients used in masonic_categorized_blog.
 */
function masonic_category_transient_flusher() {
   if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
      return;
   }
   // Like, beat it. Dig?
   delete_transient('masonic_categories');
}

add_action('edit_category', 'masonic_category_transient_flusher');
add_action('save_post', 'masonic_category_transient_flusher');